##############################################################################
#
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
#
# Copyright (c) Digital Creations.  All rights reserved.
#
# This license has been certified as Open Source(tm).
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
#
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
#
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
#
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
#
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
#
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
#
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
#
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
#
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
#
#
# Disclaimer
#
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
#
#
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
#
##############################################################################
from Products.CMFBTree.PortalBTreeFolder import PortalBTreeFolder

from LinkPropertyManager import LinkPropertyManager
import PropertyFolder
# Import permission names
import PropertyCorePermissions

beforeCreate = PropertyFolder.beforeCreate

afterCreate = PropertyFolder.afterCreate

WorkflowMethod = PropertyFolder.WorkflowMethod

InitializeClassPropertyBTreeFolder = PropertyFolder.InitializeClassPropertyFolder

factory_type_information = (
    { 'id'                : 'PropertyBTreeFolder'
      , 'meta_type'       : 'CMF PropertyBTreeFolder'
      , 'description'     : """\
Property BTree folder object."""
      , 'icon'            : 'pcore_folder_icon.gif'
      , 'product'         : 'CMFPropertyCore'
      , 'factory'         : 'manage_addPropertyBTreeFolder'
      , 'filter_content_types' : 0
      , 'immediate_view'  : 'pcore_edit_form'
      , 'actions'         :
#       ( { 'name'          : 'Folder contents'
#           , 'action'      : 'folder_contents'
#           , 'permissions' : (PropertyCorePermissions.ListFolderContents,)
#           , 'category'    : 'folder'
#           }
      ( { 'name'          : 'View'
          , 'action'      : 'pcore_view'
          , 'permissions' : (PropertyCorePermissions.View,)
          , 'category'    : 'folder'
          }
      , { 'name'          : 'Edit'
          , 'action'      : 'pcore_edit_form'
          , 'permissions' : (PropertyCorePermissions.Modify,)
          , 'category'    : 'folder'
          }
      , { 'name'          : 'Metadata'
          , 'action'      : 'metadata_edit_form'
          , 'permissions' : (PropertyCorePermissions.Modify,)
          , 'category'    : 'folder'
          }
      , { 'name'          : 'Local Roles'
          , 'action'      : 'folder_localrole_form'
          , 'permissions' : (PropertyCorePermissions.ManageProperties,)
          , 'category'    : 'folder'
          }
      , { 'name'          : 'Syndication'
          , 'action'      : 'synPropertiesForm'
          , 'permissions' : (PropertyCorePermissions.ManageProperties,)
          , 'category'    : 'folder'
          }
        )
      }
    ,)

def manage_addPropertyBTreeFolder(self, id=None, title=None, parent=None, REQUEST=None):
    """
    Create an empty property btree folder object.
    """
    id = beforeCreate(id, 'pcf', REQUEST)
    obj = PropertyBTreeFolder(id, title, parent)
    afterCreate(self, id, obj, REQUEST)
    return id

class PropertyBTreeFolder(LinkPropertyManager, PortalBTreeFolder, PropertyFolder.PropertyFolder):
    """
    PropertyBTreeFolders are property BTree folder objects for the CMF.
    """
    meta_type='CMF PropertyBTreeFolder'

    manage_options = PortalBTreeFolder.manage_options

    def __init__(self, id, title=None, parent=None
                 , property_extensible_schema__=None
                 , property_link_id_schema__=None):
        PortalBTreeFolder.__init__(self,id)
        PropertyFolder.PropertyFolder.__init__(self,id,title,parent
                                               , property_extensible_schema__
                                               , property_link_id_schema__)

    def manage_afterAdd(self, item, container):
        PropertyFolder.PropertyFolder.manage_afterAdd(self, item, container)
    def manage_beforeDelete(self, item, container):
        PropertyFolder.PropertyFolder.manage_beforeDelete(self, item, container)

def _replaceFolder(parent, id, klass=PropertyBTreeFolder):
    PropertyFolder.__replaceFolder(parent, id, klass)

_copyObj = PropertyFolder._copyObj

# Initialize the PropertyBTreeFolder class, setting up security.
InitializeClassPropertyBTreeFolder(PropertyBTreeFolder
                                   , PropertyCorePermissions.View
                                   , PropertyCorePermissions.Modify
                                   , PropertyCorePermissions.ListFolderContents
                                   )

