##############################################################################
#
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
#
# Copyright (c) Digital Creations.  All rights reserved.
#
# This license has been certified as Open Source(tm).
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
#
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
#
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
#
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
#
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
#
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
#
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
#
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
#
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
#
#
# Disclaimer
#
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
#
#
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
#
##############################################################################
from string import lower

from Products.CMFPropertyCore.PropertyContent import PropertyContent, beforeCreate, afterCreate

# Import permission names
import UsrManOrgPermissions

#######################################
# extend_properties

# Usr
def extend_propertiesUsr(self,**kw):
    self._properties = self._extend_properties((
        {'id':'email',                    'type': 'string',  'mode':'w'},
        {'id':'email_ok',                 'type': 'boolean', 'mode':'w'},
        {'id':'portal_skin',              'type': 'string',  'mode':'w'},
        {'id':'listed',                   'type': 'boolean', 'mode':'w'},
        {'id':'login_time',               'type': 'date',    'mode':'w'},
        {'id':'login_time_uagent',        'type': 'string',  'mode':'w'},
        {'id':'last_login_time',          'type': 'date',    'mode':'w'},
        {'id':'last_login_time_uagent',   'type': 'string',  'mode':'w'},
        {'id':'failed_login_time',        'type': 'date',    'mode':'w'},
        {'id':'failed_login_time_uagent', 'type': 'string',  'mode':'w'},
        {'id':'failed_login_time_cnt',    'type': 'int',     'mode':'w'},
        {'id':'man',                      'type': 'link',    'mode':'w'},
        ))
    self.manage_changeProperties(man='Man:')
    self.manage_changeProperties(email=kw.get('email',None),email_ok=kw.get('email_ok',None)
                                 , portal_skin=kw.get('portal_skin',None)
                                 , listed=kw.get('listed',None)
                                 , login_time=kw.get('login_time',None)
                                 , login_time_uagent=kw.get('login_time_uagent',None)
                                 , last_login_time=kw.get('last_login_time',None)
                                 , last_login_time_uagent=kw.get('last_login_time_uagent',None)
                                 , failed_login_time=kw.get('failed_login_time',None)
                                 , failed_login_time_uagent=kw.get('failed_login_time_uagent',None)
                                 , failed_login_time_cnt=kw.get('failed_login_time_cnt',None)
                                 , man=kw.get('man',None)
                                 )

# Man
def extend_propertiesMan(self,**kw):
    self._properties = self._extend_properties((
        {'id':'name1',       'type': 'link',   'mode':'w'},
        {'id':'name2',       'type': 'link',   'mode':'w'},
        {'id':'name3',       'type': 'link',   'mode':'w'},
        {'id':'age',         'type': 'int',    'mode':'w'},
        {'id':'dob',         'type': 'date',   'mode':'w'},
        {'id':'sex',         'type': 'string', 'mode':'w'},
        {'id':'lang',        'type': 'tokens', 'mode':'w'},
        {'id':'nationality', 'type': 'string', 'mode':'w'},
        {'id':'occupation',  'type': 'string', 'mode':'w'},
        {'id':'tel1',        'type': 'link',   'mode':'w'},
        {'id':'tel2',        'type': 'link',   'mode':'w'},
        {'id':'tel3',        'type': 'link',   'mode':'w'},
        {'id':'tel4',        'type': 'link',   'mode':'w'},
        {'id':'tel5',        'type': 'link',   'mode':'w'},
        {'id':'loc1',        'type': 'link',   'mode':'w'},
        {'id':'loc2',        'type': 'link',   'mode':'w'},
        {'id':'loc3',        'type': 'link',   'mode':'w'},
        {'id':'uri1',        'type': 'link',   'mode':'w'},
        {'id':'uri2',        'type': 'link',   'mode':'w'},
        {'id':'uri3',        'type': 'link',   'mode':'w'},
        ))
    self.manage_changeProperties(name1='Name:',name2='Name:',name3='Name:'
                                 , tel1='Tel:',tel2='Tel:',tel3='Tel:',tel4='Tel:',tel5='Tel:'
                                 , loc1='Loc:',loc2='Loc:',loc3='Loc:'
                                 , uri1='Uri:',uri2='Uri:',uri3='Uri:'
                                 )
    self.manage_changeProperties(name1=kw.get('name1',None),name2=kw.get('name2',None),name3=kw.get('name3',None)
                                 , age=kw.get('age',None)
                                 , dob=kw.get('dob',None)
                                 , sex=kw.get('sex',None)
                                 , lang=kw.get('lang',None)
                                 , nationality=kw.get('nationality',None)
                                 , occupation=kw.get('occupation',None)
                                 , tel1=kw.get('tel1',None),tel2=kw.get('tel2',None),tel3=kw.get('tel3',None),tel4=kw.get('tel4',None),tel5=kw.get('tel5',None)
                                 , loc1=kw.get('loc1',None),loc2=kw.get('loc2',None),loc3=kw.get('loc3',None)
                                 , uri1=kw.get('uri1',None),uri2=kw.get('uri2',None),uri3=kw.get('uri3',None)
                                 )
# Org
def extend_propertiesOrg(self,**kw):
    self._properties = self._extend_properties((
        {'id':'name1',       'type': 'link',   'mode':'w'},
        {'id':'name2',       'type': 'link',   'mode':'w'},
        {'id':'name3',       'type': 'link',   'mode':'w'},
        {'id':'tel1',        'type': 'link',   'mode':'w'},
        {'id':'tel2',        'type': 'link',   'mode':'w'},
        {'id':'tel3',        'type': 'link',   'mode':'w'},
        {'id':'tel4',        'type': 'link',   'mode':'w'},
        {'id':'tel5',        'type': 'link',   'mode':'w'},
        {'id':'loc1',        'type': 'link',   'mode':'w'},
        {'id':'loc2',        'type': 'link',   'mode':'w'},
        {'id':'loc3',        'type': 'link',   'mode':'w'},
        {'id':'uri1',        'type': 'link',   'mode':'w'},
        {'id':'uri2',        'type': 'link',   'mode':'w'},
        {'id':'uri3',        'type': 'link',   'mode':'w'},
        ))
    self.manage_changeProperties(name1='Name:',name2='Name:',name3='Name:'
                                 , tel1='Tel:',tel2='Tel:',tel3='Tel:',tel4='Tel:',tel5='Tel:'
                                 , loc1='Loc:',loc2='Loc:',loc3='Loc:'
                                 , uri1='Uri:',uri2='Uri:',uri3='Uri:'
                                 )
    self.manage_changeProperties(name1=kw.get('name1',None),name2=kw.get('name2',None),name3=kw.get('name3',None)
                                 , tel1=kw.get('tel1',None),tel2=kw.get('tel2',None),tel3=kw.get('tel3',None),tel4=kw.get('tel4',None),tel5=kw.get('tel5',None)
                                 , loc1=kw.get('loc1',None),loc2=kw.get('loc2',None),loc3=kw.get('loc3',None)
                                 , uri1=kw.get('uri1',None),uri2=kw.get('uri2',None),uri3=kw.get('uri3',None)
                                 )
# Name
def extend_propertiesName(self,**kw):
    self._properties= self._extend_properties((
        {'id':'part1',   'type': 'string', 'mode':'w'},
        {'id':'part2',   'type': 'string', 'mode':'w'},
        {'id':'part3',   'type': 'string', 'mode':'w'},
        {'id':'part4',   'type': 'string', 'mode':'w'},
        ))
    self.manage_changeProperties(part1=kw.get('part1',None),part2=kw.get('part2',None),part3=kw.get('part3',None),part4=kw.get('part4',None)
                                 )
# Tel
def extend_propertiesTel(self,**kw):
    self._properties = self._extend_properties((
        {'id':'country', 'type': 'string', 'mode':'w'},
        {'id':'area',    'type': 'string', 'mode':'w'},
        {'id':'num1',    'type': 'string', 'mode':'w'},
        {'id':'num2',    'type': 'string', 'mode':'w'},
        {'id':'ext',     'type': 'string', 'mode':'w'},
        ))
    self.manage_changeProperties(country=kw.get('country',None)
                                 , area=kw.get('area',None)
                                 , num1=kw.get('num1',None),num2=kw.get('num2',None)
                                 , ext=kw.get('ext',None)
                                 )
# Loc
def extend_propertiesLoc(self,**kw):
    self._properties = self._extend_properties((
        {'id':'country', 'type': 'string', 'mode':'w'},
        {'id':'zip',     'type': 'string', 'mode':'w'},
        {'id':'state',   'type': 'string', 'mode':'w'},
        {'id':'city',    'type': 'string', 'mode':'w'},
        {'id':'addr1',   'type': 'string', 'mode':'w'},
        {'id':'addr2',   'type': 'string', 'mode':'w'},
        {'id':'addr3',   'type': 'string', 'mode':'w'},
        ))
    self.manage_changeProperties(country=kw.get('country',None)
                                 , zip=kw.get('zip',None)
                                 , state=kw.get('state',None)
                                 , city=kw.get('city',None)
                                 , addr1=kw.get('addr1',None),addr2=kw.get('addr2',None),addr3=kw.get('addr3',None)
                                 )
# Uri
def extend_propertiesUri(self,**kw):
    self._properties = self._extend_properties((
        {'id':'uri', 'type': 'string', 'mode':'w'},
        ))
    self.manage_changeProperties(uri=kw.get('uri',None)
                                 )

#######################################
# manage_Add

# Usr
def manage_addUsr(self,id=None,title=None,parent=None,REQUEST=None,**kw):
    """
    Create a usr.
    """
    id = beforeCreate(id, 'usr', REQUEST)
    obj = PropertyContent(id, title, parent)
    apply(extend_propertiesUsr,(obj,),kw)
    afterCreate(self, id, obj, REQUEST)
    return id
# Man
def manage_addMan(self,id=None,title=None,parent=None,REQUEST=None,**kw):
    """
    Create a man.
    """
    id = beforeCreate(id, 'man', REQUEST)
    obj = PropertyContent(id, title, parent)
    apply(extend_propertiesMan,(obj,),kw)
    afterCreate(self, id, obj, REQUEST)
    return id
# Org
def manage_addOrg(self,id=None,title=None,parent=None,REQUEST=None,**kw):
    """
    Create a org.
    """
    id = beforeCreate(id, 'org', REQUEST)
    obj = PropertyContent(id, title, parent)
    apply(extend_propertiesOrg,(obj,),kw)
    afterCreate(self, id, obj, REQUEST)
    return id
# Name
def manage_addName(self,id=None,title=None,parent=None,REQUEST=None,**kw):
    """
    Create a name.
    """
    id = beforeCreate(id, 'name', REQUEST)
    obj = PropertyContent(id, title, parent)
    apply(extend_propertiesName,(obj,),kw)
    afterCreate(self, id, obj, REQUEST)
    return id
# Tel
def manage_addTel(self,id=None,title=None,parent=None,REQUEST=None,**kw):
    """
    Create a tel.
    """
    id = beforeCreate(id, 'tel', REQUEST)
    obj = PropertyContent(id, title, parent)
    apply(extend_propertiesTel,(obj,),kw)
    afterCreate(self, id, obj, REQUEST)
    return id
# Loc
def manage_addLoc(self,id=None,title=None,parent=None,REQUEST=None,**kw):
    """
    Create a loc.
    """
    id = beforeCreate(id, 'loc', REQUEST)
    obj = PropertyContent(id, title, parent)
    apply(extend_propertiesLoc,(obj,),kw)
    afterCreate(self, id, obj, REQUEST)
    return id
# Uri
def manage_addUri(self,id=None,title=None,parent=None,REQUEST=None,**kw):
    """
    Create a uri.
    """
    id = beforeCreate(id, 'uri', REQUEST)
    obj = PropertyContent(id, title, parent)
    apply(extend_propertiesUri,(obj,),kw)
    afterCreate(self, id, obj, REQUEST)
    return id

#######################################
# factory_type_information

# template
factory_type_information_template = (
    { 'id'                : 'UsrManOrg'
      , 'meta_type'       : 'CMF UsrManOrg'
      , 'description'     : """\
UsrManOrg content object."""
      , 'icon'            : 'pcore_object_icon.gif'
      , 'product'         : 'CMFUsrManOrg'
      , 'factory'         : 'manage_addUsrManOrg'
      , 'immediate_view'  : 'pcore_edit_form'
      , 'actions'         :
      ( { 'name'          : 'View'
          , 'action'      : 'pcore_view'
          , 'permissions' : (UsrManOrgPermissions.View,)
          }
      , { 'name'          : 'Edit'
          , 'action'      : 'pcore_edit_form'
          , 'permissions' : (UsrManOrgPermissions.Modify,)
          }
      , { 'name'          : 'Metadata'
          , 'action'      : 'metadata_edit_form'
          , 'permissions' : (UsrManOrgPermissions.Modify,)
          }
        )
      }
    ,)

factory_type_information = []
for i in ('Usr','Man','Org','Name','Tel','Loc','Uri'):
    import copy
    ft = copy.deepcopy(factory_type_information_template)
    ft[0].update({
        'id'            : i
        , 'meta_type'   : 'CMF %s' % i
        , 'description' : '%s object.' % i
        , 'icon'        : '%s_icon.gif' % lower(i)
        , 'factory'     : 'manage_add%s' % i
        })
    factory_type_information.extend(ft)

factory_type_information = tuple(factory_type_information)
